/**
 * Copyright (c) 2009-2012, Lukas Eder, lukas.eder@gmail.com
 * All rights reserved.
 *
 * This software is licensed to you under the Apache License, Version 2.0
 * (the "License"); You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * . Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 * . Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * . Neither the name "jOOQ" nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.jooq.util;


/**
 * @author Lukas Eder
 */
public class MasterDataTypeDefinition implements DataTypeDefinition {

    final TableDefinition    table;
    final DataTypeDefinition underlying;

    public MasterDataTypeDefinition(TableDefinition table, DataTypeDefinition underlying) {
        this.table = table;
        this.underlying = underlying;
    }

    @Override
    public final String getType() {
        return underlying.getType();
    }

    @Override
    public final int getLength() {
        return underlying.getLength();
    }

    @Override
    public final int getPrecision() {
        return underlying.getPrecision();
    }

    @Override
    public final int getScale() {
        return underlying.getScale();
    }

    @Override
    public final String getUserType() {
        return underlying.getUserType();
    }

    @Override
    public final boolean isGenericNumberType() {
        return underlying.isGenericNumberType();
    }

    @Override
    public final boolean isUDT() {
        return false;
    }

    @Override
    public final Database getDatabase() {
        return underlying.getDatabase();
    }

    @Override
    public final SchemaDefinition getSchema() {
        return underlying.getSchema();
    }
}
